@@ -1,5 +1,6 @@
 from dataclasses import dataclass
-from typing import Optional, Dict, List
+from typing import Optional, Dict, List, Union
+from uuid import UUID
 
 from box import Box
 
@@ -112,3 +113,12 @@ class UserService:
             if collector.get('active'):
                 return idx
         complain_and_abort('No active collector found')
+
+    def get_warehouse_for_connection(self, connection_id: Union[str, UUID]) -> Optional[Box]:
+        """
+        Get warehouse for the given connection id
+        """
+        for warehouse in self.warehouses:
+            for connection in warehouse.get('connections', []):
+                if str(connection_id) == connection.get('uuid'):
+                    return Box(warehouse)
