@@ -5,6 +5,7 @@ import click_config_file
 
 import montecarlodata.settings as settings
 from montecarlodata.common import create_mc_client
+from montecarlodata.integrations.configure.bi.bi import BiService
 from montecarlodata.integrations.onboarding.bi.reports import ReportsOnboardingService
 from montecarlodata.common.commands import DISAMBIGUATE_DC_OPTIONS
 from montecarlodata.common.resources import CloudResourceService
@@ -642,6 +643,55 @@ def add_looker(ctx, **kwargs):
     ReportsOnboardingService(config=ctx['config']).onboard_looker_metadata(**kwargs)
 
 
+@integrations.command(help="""
+Create or refresh details of BI warehouse sources. Warehouse sources are warehouses connected to a BI container. 
+
+If only the bi-container-id parameter is supplied, then the behavior will be the following: 
+\b
+\n
+(1) All warehouse sources in the customer's BI system will be matched against warehouses in Monte Carlo. 
+\b
+\n
+(2) If all of the customer's BI warehouse sources have a match in Monte Carlo, then the warehouse source details will be
+saved.
+\b
+\n
+(3) Otherwise, the response will contain the details of customer's BI warehouse sources and Monte Carlo warehouses. The 
+caller will then need to manually save the warehouse source details by specifying the warehouse-source-details
+parameter.
+\b
+\n
+If the warehouse-source-details parameter is also supplied, then the warehouses will be validated and saved.
+""")
+@click.pass_obj
+@click.option('--bi-container-id',
+              help='ID of the BI container for which to refresh warehouse sources.',
+              required=True)
+@click.option('--warehouse-source-details', help="""
+              An optional JSON array of warehouse sources. If supplied, these warehouse sources will be created. If an
+              entry with the same bi_container_id, warehouse_resource_id and warehouse_resource_type is found, its
+              bi_warehouse_id will be updated.
+              
+              Each JSON object in this array has the following fields:
+              \b
+              \n
+              bi_warehouse_id: The ID of the warehouse in the customer's ID space.
+              \b
+              \n
+              warehouse_resource_id: The ID of the warehouse Monte Carlo's ID space.
+              \b
+              \n
+              warehouse_resource_type: The type of the warehouse.
+              \b
+              \n
+              E.g. --warehouse-source-details '[{"bi_warehouse_id":"0dd5d40e-8749-71cb-9fa5-2e33b570ff43", 
+              "warehouse_resource_id": "11b1ad6f-e35c-4532-84d8-2fc88bd53660", "warehouse_resource_type": "snowflake"}]'
+              """,
+              required=False, callback=validate_json_callback)
+def refresh_bi_to_warehouse_connections(ctx, bi_container_id, warehouse_source_details, **kwargs):
+    BiService(config=ctx['config']).refresh_bi_to_warehouse_connections(bi_container_id, warehouse_source_details)
+
+
 @integrations.command(help=f'Setup a Looker ML (git) integration. {BI_VERBIAGE}.')
 @click.pass_obj
 @click.option('--ssh-key', help='The ssh key for git ssh integrations.', required=False,
