@@ -185,19 +185,24 @@ class BaseOnboardingService:
         if (connection_type in MAIN_CONNECTION_TYPES or warehouse_type != DATA_LAKE_WAREHOUSE_TYPE) and create_warehouse:
             return {'createWarehouseType': warehouse_type}
 
-        warehouses = self._user_service.warehouses
         name = onboarding_config.warehouse_name
 
+        dw_id = self._get_warehouse_id_from_name(name)
+        return {'dwId': dw_id}
+
+    def _get_warehouse_id_from_name(self, name: Optional[str]) -> str:
+        warehouses = self._user_service.warehouses
+
         # If it is not a new warehouse, find the warehouse with the given name to create the new connection belonging
         # to it. If the name is not found, it is an error.
         if name:
             warehouses = [warehouse for warehouse in warehouses if warehouse.get('name') == name]
             if warehouses:
-                return {'dwId': warehouses[0]['uuid']}
+                return warehouses[0]['uuid']
             complain_and_abort('Could not find warehouse with given name')
         # Name is optional if there is only one warehouse.
         elif len(warehouses) == 1:
-            return {'dwId': warehouses[0]['uuid']}
+            return warehouses[0]['uuid']
         # If more than one warehouse exists, name is required.
         else:
             complain_and_abort('Name is required to disambiguate lake warehouses')
