@@ -6,8 +6,11 @@ from pathlib import Path
 # Verbose error logging
 MCD_VERBOSE_ERRORS = os.getenv('MCD_VERBOSE_ERRORS', False) in (True, 'true', 'True')
 
-# MCD API endpoint
-MCD_API_ENDPOINT = os.getenv('MCD_API_ENDPOINT', 'https://api.getmontecarlo.com/graphql')
+# MCD API endpoint. Overwrites config-file
+MCD_API_ENDPOINT = os.getenv('MCD_API_ENDPOINT')
+
+# Default MCD API endpoint when no env or config file setting is available
+MCD_DEFAULT_API_ENDPOINT = 'https://api.getmontecarlo.com/graphql'
 
 # MCD ID header (for use in local development and testing)
 MCD_USER_ID_HEADER = os.getenv('MCD_USER_ID_HEADER')
