@@ -369,6 +369,52 @@ class BaseOnboardingTest(TestCase):
             }
         )
 
+    def test_connection_with_multiple_warehouses_adding_connection_to_existing_lake_warehouse(self):
+        key, conn_id, dw_id = 'foo', 'bar', '456'
+        self._user_service_mock.warehouses = [
+            {'uuid': '123', 'connectionType': 'redshift', 'name': 'redshift'},
+            {'uuid': dw_id, 'connectionType': 'data-lake', 'name': 'data-lake'}
+        ]
+
+        self._request_wrapper_mock.make_request_v2.return_value = MonolithResponse(data={'connection': {'uuid': conn_id}})
+        self.assertTrue(self._service._add_connection(key, OnboardingConfiguration(
+            connection_type='hive-mysql', warehouse_name='data-lake', create_warehouse=False, **{}
+        )))
+
+        self._request_wrapper_mock.make_request_v2.assert_called_once_with(
+            query=ADD_CONNECTION_MUTATION,
+            operation='addConnection',
+            variables={
+                'key': key,
+                'connectionType': 'hive-mysql',
+                'dwId': dw_id,
+                'name': 'data-lake'
+            }
+        )
+
+    def test_connection_with_multiple_warehouses_adding_lake_warehouse(self):
+        key, conn_id, dw_id = 'foo', 'bar', '456'
+        self._user_service_mock.warehouses = [
+            {'uuid': '123', 'connectionType': 'redshift', 'name': 'redshift'},
+            {'uuid': dw_id, 'connectionType': 'data-lake', 'name': 'data-lake'}
+        ]
+
+        self._request_wrapper_mock.make_request_v2.return_value = MonolithResponse(data={'connection': {'uuid': conn_id}})
+        self.assertTrue(self._service._add_connection(key, OnboardingConfiguration(
+            connection_type='hive-mysql', warehouse_name='data-lake2', create_warehouse=True, **{}
+        )))
+
+        self._request_wrapper_mock.make_request_v2.assert_called_once_with(
+            query=ADD_CONNECTION_MUTATION,
+            operation='addConnection',
+            variables={
+                'key': key,
+                'connectionType': 'hive-mysql',
+                'createWarehouseType': 'data-lake',
+                'name': 'data-lake2'
+            }
+        )
+
     def test_connection_with_job_types(self):
         key, conn_id, jobs = 'foo', 'bar', ['qux']
         config = OnboardingConfiguration(connection_type=_SAMPLE_CONNECTION_PATH, **{})
