@@ -23,13 +23,11 @@ class DatabricksMetastoreOnboardingTest(TestCase):
     def setUp(self) -> None:
         self._mc_client_mock = Mock(autospec=Client)
         self._user_service_mock = Mock(autospec=UserService)
-        self._request_wrapper_mock = Mock(autospec=GqlWrapper)
         self._aws_wrapper_mock = Mock(autospec=AwsClientWrapper)
 
         self._service = DatabricksOnboardingService(
             _SAMPLE_CONFIG,
             mc_client=self._mc_client_mock,
-            request_wrapper=self._request_wrapper_mock,
             aws_wrapper=self._aws_wrapper_mock,
             user_service=self._user_service_mock
         )
@@ -54,6 +52,7 @@ class DatabricksMetastoreOnboardingTest(TestCase):
             databricks_job_name='databricks_job_name',
             databricks_notebook_path='databricks_notebook_path',
             databricks_notebook_source='databricks_notebook_path',
+            databricks_notebook_version='123',
         )
 
         self._mc_client_mock.side_effect = [
@@ -66,7 +65,8 @@ class DatabricksMetastoreOnboardingTest(TestCase):
                         workspace_job_name=job_info['databricks_job_name'],
                         workspace_notebook_path=job_info['databricks_notebook_path'],
                         notebook_source=job_info['databricks_notebook_source'],
-                    )
+                        notebook_version=job_info['databricks_notebook_version'],
+                    ),
                 )
             )),
             Box(dict(get_projects=dict(projects=projects)))
@@ -110,6 +110,7 @@ class DatabricksMetastoreOnboardingTest(TestCase):
             databricks_job_name='databricks_job_name',
             databricks_notebook_path='databricks_notebook_path',
             databricks_notebook_source='databricks_notebook_path',
+            databricks_notebook_version='123',
         )
 
         databricks_config = {
@@ -129,6 +130,7 @@ class DatabricksMetastoreOnboardingTest(TestCase):
                         workspace_job_name=job_info['databricks_job_name'],
                         workspace_notebook_path=job_info['databricks_notebook_path'],
                         notebook_source=job_info['databricks_notebook_source'],
+                        notebook_version=job_info['databricks_notebook_version'],
                     )
                 )
             )),
@@ -165,3 +167,42 @@ class DatabricksMetastoreOnboardingTest(TestCase):
             # This is the same way that the SDK tests that two calls are the same 
             # https://github.com/monte-carlo-data/python-sdk/blob/62f1ab7a8404119da4621b224e77bbbdd5dc938c/tests/test_operations.py#L21
             self.assertEqual(str(self._mc_client_mock.call_args_list[i]).strip(), str(expected_call).strip())
+
+    def test_update_databricks_notebook_gql_calls(self):
+        options = {
+            'connection_id': '123456789'
+        }
+        self._service.update_databricks_notebook(**options)
+        expected_mutation = Mutation()
+        expected_mutation.update_databricks_notebook(**options)
+        expected_call = call(expected_mutation)
+        self.assertEqual(str(self._mc_client_mock.call_args_list[0]).strip(), str(expected_call).strip())
+
+    def test_get_databricks_job_info_gql_calls(self):
+        options = {
+            'connection_id': '123456789'
+        }
+        self._mc_client_mock.return_value = Mock(
+            get_databricks_metadata_job_info = [
+                Mock(
+                    workspace_job_id='123456',
+                    workspace_job_name='test_job_name',
+                    workspace_notebook_path='/some/path',
+                    notebook_source='test_source',
+                    notebook_version='123',
+                )
+            ]
+        )
+        self._service.get_databricks_job_info(**options)
+        expected_query = Query()
+        expected_query.get_databricks_metadata_job_info(**options)
+        expected_call = call(expected_query)
+        self.assertEqual(str(self._mc_client_mock.call_args_list[0]).strip(), str(expected_call).strip())
+
+    def test_get_current_databricks_notebook_version_gql_calls(self):
+        self._service.get_current_databricks_notebook_version()
+        expected_query = Query()
+        expected_query.get_current_databricks_notebook_version()
+        expected_call = call(expected_query)
+        self.assertEqual(str(self._mc_client_mock.call_args_list[0]).strip(), str(expected_call).strip())
+
